@@ -6,7 +6,9 @@ and online at https://docs.plasmapy.org (accessible also using the
 """
 __all__ = [
     "online_help",
+    "analysis",
     "diagnostics",
+    "dispersion",
     "formulary",
     "particles",
     "plasma",
@@ -20,15 +22,24 @@ __all__ = [
 # This is the same check as the one at the top of setup.py
 import sys
 
-if sys.version_info < (3, 7):
-    raise Exception("PlasmaPy does not support Python < 3.7")
+if sys.version_info < (3, 8):  # coverage: ignore
+    raise ImportError("PlasmaPy does not support Python < 3.8")
 
 # Packages may add whatever they like to this file, but
 # should keep this content at the top.
 # ----------------------------------------------------------------------------
-import pkg_resources
+from importlib.metadata import PackageNotFoundError, version
 
-from plasmapy import diagnostics, formulary, particles, plasma, simulation, utils
+from plasmapy import (
+    analysis,
+    diagnostics,
+    dispersion,
+    formulary,
+    particles,
+    plasma,
+    simulation,
+    utils,
+)
 
 # define version
 try:
@@ -42,8 +53,8 @@ try:
     #       frozen to the version at time of install.
     #
     #: PlasmaPy version string
-    __version__ = pkg_resources.get_distribution("plasmapy").version
-except pkg_resources.DistributionNotFound:
+    __version__ = version("plasmapy")
+except PackageNotFoundError:
     # package is not installed
     fallback_version = "unknown"
     try:
@@ -100,13 +111,13 @@ def online_help(query: str):
 
     url = (
         "http://docs.plasmapy.org/en/stable/search.html?"
-        "{0}&check_keywords=yes&area=default"
+        "{}&check_keywords=yes&area=default"
     ).format(urlencode({"q": query}))
 
-    if query.lower() in ("unit", "units", "quantity", "quantities"):
+    if query.lower() in {"unit", "units", "quantity", "quantities"}:
         url = "http://docs.astropy.org/en/stable/units/"
 
     webbrowser.open(url)
 
 
-del pkg_resources, sys
+del sys
