@@ -7,9 +7,8 @@ __all__ = [
     "plasma_dispersion_func",
     "plasma_dispersion_func_deriv",
 ]
-# TODO: import plasmapy.dispersion.numerical once it is populated with
-#       functionality (i.e. expose to namespace)
-from plasmapy.dispersion import analytical
+
+from plasmapy.dispersion import analytical, numerical
 from plasmapy.dispersion.dispersionfunction import (
     plasma_dispersion_func,
     plasma_dispersion_func_deriv,
