@@ -2,8 +2,7 @@
 The `~plasmapy.dispersion.analytical` subpackage contains functionality
 associated with analytical dispersion solutions.
 """
-__all__ = [
-    "two_fluid",
-]
+__all__ = ["two_fluid", "stix"]
 
+from plasmapy.dispersion.analytical.stix_ import stix
 from plasmapy.dispersion.analytical.two_fluid_ import two_fluid
