@@ -10,8 +10,9 @@ import warnings
 
 from astropy import units as u
 from numbers import Integral, Real
-from typing import List, Optional, Union
+from typing import List, NoReturn, Optional, Union
 
+from plasmapy.particles.atomic import ionic_levels
 from plasmapy.particles.decorators import particle_input
 from plasmapy.particles.exceptions import (
     ChargeError,
@@ -19,10 +20,8 @@ from plasmapy.particles.exceptions import (
     ParticleError,
 )
 from plasmapy.particles.particle_class import CustomParticle, Particle
-from plasmapy.particles.particle_collections import ionic_levels, ParticleList
+from plasmapy.particles.particle_collections import ParticleList
 from plasmapy.utils.decorators import validate_quantities
-from plasmapy.utils.decorators.deprecation import deprecated
-from plasmapy.utils.exceptions import PlasmaPyFutureWarning
 
 _number_density_errmsg = (
     "Number densities must be Quantity objects with units of inverse volume."
@@ -35,14 +34,14 @@ class IonicLevel:
 
     Parameters
     ----------
-    ion: `~plasmapy.particles.particle_class.ParticleLike`
+    ion : |atom-like|
         The ion for the corresponding ionic fraction.
 
-    ionic_fraction: real number between 0 and 1, optional
+    ionic_fraction : real number, optional
         The fraction of an element or isotope that is at this ionization
-        level.
+        level. Must be between 0 and 1, inclusive.
 
-    number_density: `~astropy.units.Quantity`, optional
+    number_density : `~astropy.units.Quantity`, optional
         The number density of this ion.
 
     See Also
@@ -63,32 +62,27 @@ class IonicLevel:
 
     def __eq__(self, other):
 
-        try:
-            if self.ionic_symbol != other.ionic_symbol:
-                return False
+        if not isinstance(other, IonicLevel):
+            return False
 
-            ionic_fraction_within_tolerance = np.isclose(
-                self.ionic_fraction,
-                other.ionic_fraction,
-                rtol=1e-15,
-            )
+        if self.ionic_symbol != other.ionic_symbol:
+            return False
 
-            number_density_within_tolerance = u.isclose(
-                self.number_density,
-                other.number_density,
-                rtol=1e-15,
-            )
+        ionic_fraction_within_rtol = u.isclose(
+            self.ionic_fraction,
+            other.ionic_fraction,
+            rtol=1e-15,
+            equal_nan=True,
+        )
 
-            return all(
-                [ionic_fraction_within_tolerance, number_density_within_tolerance]
-            )
+        number_density_within_rtol = u.isclose(
+            self.number_density,
+            other.number_density,
+            rtol=1e-15,
+            equal_nan=True,
+        )
 
-        except TypeError as exc:
-            raise TypeError(
-                "Unable to ascertain equality between the following objects:\n"
-                f"  {self}\n"
-                f"  {other}"
-            ) from exc
+        return ionic_fraction_within_rtol and number_density_within_rtol
 
     @particle_input
     def __init__(
@@ -118,21 +112,6 @@ class IonicLevel:
         """The charge number of the ion."""
         return self.ion.charge_number
 
-    @property
-    @deprecated(
-        since="0.7.0",
-        name="integer_charge",
-        message=(
-            "The integer_charge attribute of IonicLevel has been "
-            "deprecated and will be removed in a future release.  Use "
-            "charge_number instead."
-        ),
-        warning_type=PlasmaPyFutureWarning,
-    )
-    def integer_charge(self) -> Integral:
-        """The charge number of the ion."""
-        return self.charge_number
-
     @property
     def ionic_fraction(self) -> Real:
         r"""
@@ -144,7 +123,7 @@ class IonicLevel:
         An ionic fraction must be in the interval :math:`[0, 1]`.
 
         If no ionic fraction is specified, then this attribute will be
-        assigned the value of `~numpy.nan`.
+        assigned the value of |nan|.
         """
         return self._ionic_fraction
 
@@ -155,8 +134,8 @@ class IonicLevel:
         else:
             try:
                 out_of_range = ionfrac < 0 or ionfrac > 1
-            except TypeError:
-                raise TypeError(f"Invalid ionic fraction: {ionfrac}")
+            except TypeError as ex:
+                raise TypeError(f"Invalid ionic fraction: {ionfrac}") from ex
             else:
                 if out_of_range:
                     raise ValueError("The ionic fraction must be between 0 and 1.")
@@ -195,12 +174,12 @@ class IonizationState:
 
     Parameters
     ----------
-    particle: `~plasmapy.particles.particle_class.ParticleLike`
+    particle : |particle-like|
         A `str` or `~plasmapy.particles.particle_class.Particle` instance
         representing an element, isotope, or ion; or an integer representing
         the atomic number of an element.
 
-    ionic_fractions: `~numpy.ndarray`, `list`, `tuple`, or `~astropy.units.Quantity`; optional
+    ionic_fractions : `~numpy.ndarray`, `list`, `tuple`, or `~astropy.units.Quantity`; optional
         The ionization fractions of an element, where the indices
         correspond to the charge number.  This argument should contain the
         atomic number plus one items, and must sum to one within an
@@ -209,17 +188,16 @@ class IonizationState:
         the number densities of each neutral/ion.  This argument cannot
         be specified when ``particle`` is an ion.
 
-    T_e: `~astropy.units.Quantity`, keyword-only, optional
+    T_e : `~astropy.units.Quantity`, |keyword-only|, optional
         The electron temperature or thermal energy per electron.
 
-    n_elem: `~astropy.units.Quantity`, keyword-only, optional
+    n_elem : `~astropy.units.Quantity`, |keyword-only|, optional
         The number density of the element, including neutrals and all
         ions.
 
-    tol: `float` or integer, keyword-only, optional
+    tol : `float` or integer, |keyword-only|, optional, default: ``1e-15``
         The absolute tolerance used by `~numpy.isclose` and similar
         functions when testing normalizations and making comparisons.
-        Defaults to ``1e-15``.
 
     Raises
     ------
@@ -265,6 +243,7 @@ class IonizationState:
 
     # TODO: Add in functionality to find equilibrium ionization states.
 
+    @particle_input(require="element")
     @validate_quantities(
         T_e={"unit": u.K, "equivalencies": u.temperature_energy()},
         T_i={
@@ -273,7 +252,6 @@ class IonizationState:
             "none_shall_pass": True,
         },
     )
-    @particle_input(require="element")
     def __init__(
         self,
         particle: Particle,
@@ -285,10 +263,6 @@ class IonizationState:
         n_elem: u.m**-3 = np.nan * u.m**-3,
         tol: Union[float, int] = 1e-15,
     ):
-        """
-        Initialize an `~plasmapy.particles.ionization_state.IonizationState`
-        instance.
-        """
         self._number_of_particles = particle.atomic_number + 1
 
         if particle.is_ion or particle.is_category(require=("uncharged", "element")):
@@ -308,7 +282,14 @@ class IonizationState:
             self.T_e = T_e
             self.T_i = T_i
             self.kappa = kappa
+            self.n_elem = n_elem
+            self.ionic_fractions = ionic_fractions
 
+        except TypeError as exc:
+            raise ParticleError(
+                f"Unable to create IonizationState object for {particle.symbol}."
+            ) from exc
+        else:
             if (
                 not np.isnan(n_elem)
                 and isinstance(ionic_fractions, u.Quantity)
@@ -319,9 +300,6 @@ class IonizationState:
                     "through both n_elem and ionic_fractions."
                 )
 
-            self.n_elem = n_elem
-            self.ionic_fractions = ionic_fractions
-
             if ionic_fractions is None and not np.isnan(self.T_e):
                 warnings.warn(
                     "Collisional ionization equilibration has not yet "
@@ -329,11 +307,6 @@ class IonizationState:
                     "ionic fractions."
                 )
 
-        except TypeError as exc:
-            raise ParticleError(
-                f"Unable to create IonizationState object for {particle.symbol}."
-            ) from exc
-
     def __str__(self) -> str:
         return f"<IonizationState instance for {self.base_particle}>"
 
@@ -423,10 +396,7 @@ class IonizationState:
 
         """
         if not isinstance(other, IonizationState):
-            raise TypeError(
-                "An instance of the IonizationState class may only be "
-                "compared with another IonizationState instance."
-            )
+            return False
 
         same_element = self.element == other.element
         same_isotope = self.isotope == other.isotope
@@ -497,10 +467,12 @@ class IonizationState:
 
         try:
             if np.min(fractions) < 0:
-                raise ParticleError("Cannot have negative ionic fractions.")
+                raise ParticleError(  # noqa: TC301
+                    "Cannot have negative ionic fractions."
+                )
 
             if len(fractions) != self.atomic_number + 1:
-                raise ParticleError(
+                raise ParticleError(  # noqa: TC301
                     "The length of ionic_fractions must be "
                     f"{self.atomic_number + 1}."
                 )
@@ -541,7 +513,7 @@ class IonizationState:
         total = np.sum(self._ionic_fractions)
         return np.isclose(total, 1, atol=tol, rtol=0)
 
-    def normalize(self) -> None:
+    def normalize(self) -> NoReturn:
         """
         Normalize the ionization state distribution (if set) so that the
         sum of the ionic fractions becomes equal to one.
@@ -662,7 +634,7 @@ class IonizationState:
             raise ParticleError(error_str)
 
     @property
-    def kappa(self) -> np.real:
+    def kappa(self) -> Real:
         """
         The κ parameter for a kappa distribution function for electrons.
 
@@ -730,21 +702,6 @@ class IonizationState:
         """An array of the charge numbers."""
         return self.to_list().charge_number
 
-    @property
-    @deprecated(
-        since="0.7.0",
-        name="integer_charges",
-        message=(
-            "The integer_charges attribute of IonizationState has been "
-            "deprecated and will be removed in a future release.  Use "
-            "charge_numbers instead."
-        ),
-        warning_type=PlasmaPyFutureWarning,
-    )
-    def integer_charges(self) -> np.ndarray:
-        """An array of the charge numbers."""
-        return self.charge_numbers
-
     @property
     def Z_mean(self) -> np.float64:
         """Return the mean charge number."""
@@ -757,7 +714,7 @@ class IonizationState:
 
     @property
     def Z_rms(self) -> np.float64:
-        """The root mean square charge number."""
+        """The root-mean-square charge number."""
         return np.sqrt(np.sum(self.ionic_fractions * self.charge_numbers**2))
 
     @property
@@ -859,18 +816,17 @@ class IonizationState:
 
         Parameters
         ----------
-        include_neutrals : `bool`, optional, keyword-only
+        include_neutrals : `bool`, optional, |keyword-only|, default: `True`
             If `True`, include neutrals when calculating the mean values
             of the different particles.  If `False`, exclude neutrals.
-            Defaults to `True`.
 
-        use_rms_charge : `bool`, optional, keyword-only
-            If `True`, use the root mean square charge instead of the
-            mean charge. Defaults to `False`.
+        use_rms_charge : `bool`, optional, |keyword-only|, default: `False`
+            If `True`, use the root-mean-square charge instead of the
+            mean charge.
 
-        use_rms_mass : `bool`, optional, keyword-only
-            If `True`, use the root mean square mass instead of the mean
-            mass. Defaults to `False`.
+        use_rms_mass : `bool`, optional, |keyword-only|, default: `False`
+            If `True`, use the root-mean-square mass instead of the mean
+            mass.
 
         Returns
         -------
@@ -899,15 +855,14 @@ class IonizationState:
 
     def summarize(self, minimum_ionic_fraction: Real = 0.01) -> None:
         """
-        Print quicklook information for an
-        `~plasmapy.particles.ionization_state.IonizationState` instance.
+        Print quicklook information.
 
         Parameters
         ----------
-        minimum_ionic_fraction: real number
+        minimum_ionic_fraction : real number, default: ``0.01``
             If the ionic fraction for a particular ionization state is
             below this level, then information for it will not be
-            printed.  Defaults to 0.01.
+            printed.
 
         Examples
         --------
