@@ -8,7 +8,7 @@ import astropy.units as u
 import numpy as np
 
 from numbers import Integral, Real
-from typing import Dict, List, Optional, Tuple, Union
+from typing import Dict, List, NoReturn, Optional, Tuple, Union
 
 from plasmapy.particles.atomic import atomic_number
 from plasmapy.particles.exceptions import (
@@ -23,8 +23,8 @@ from plasmapy.particles.symbols import particle_symbol
 from plasmapy.utils.decorators import validate_quantities
 
 
-def _atomic_number_and_mass_number(p: Particle):
-    return (p.atomic_number, p.mass_number if p.isotope else 0)
+def _atomic_number_and_mass_number(p: ParticleLike):
+    return p.atomic_number, p.mass_number if p.isotope else 0
 
 
 class IonizationStateCollection:
@@ -34,7 +34,7 @@ class IonizationStateCollection:
 
     Parameters
     ----------
-    inputs: `list`, `tuple`, or `dict`
+    inputs : `list`, `tuple`, or `dict`
         A `list` or `tuple` of elements or isotopes (if ``T_e`` is
         provided); a `list` of `~plasmapy.particles.ionization_state.IonizationState`
         instances; a `dict` with elements or isotopes as keys and
@@ -42,31 +42,31 @@ class IonizationStateCollection:
         with elements or isotopes as keys and `~astropy.units.Quantity`
         instances with units of number density.
 
-    abundances: `dict`, optional, keyword-only
+    abundances : `dict`, optional, |keyword-only|
         A `dict` with `~plasmapy.particles.particle_class.ParticleLike`
         objects used as the keys and the corresponding relative abundance as the
         values.  The values must be positive real numbers.
 
-    log_abundances: `dict`, optional, keyword-only
+    log_abundances : `dict`, optional, |keyword-only|
         A `dict` with `~plasmapy.particles.particle_class.ParticleLike`
         objects used as the keys and the corresponding base 10 logarithms of their
         relative abundances as the values.  The values must be real numbers.
 
-    n0: `~astropy.units.Quantity`, optional, keyword-only
+    n0 : `~astropy.units.Quantity`, optional, |keyword-only|
         The number density normalization factor corresponding to the
         abundances.  The number density of each element is the product
         of its abundance and ``n0``.
 
-    T_e: `~astropy.units.Quantity`, optional, keyword-only
+    T_e : `~astropy.units.Quantity`, optional, |keyword-only|
         The electron temperature in units of temperature or thermal
         energy per particle.
 
-    kappa: `float`, optional, keyword-only
+    kappa : `float`, optional, |keyword-only|
         The value of kappa for a kappa distribution function.
 
-    tol: `float` or `integer`, optional, keyword-only
+    tol : `float` or `integer`, optional, |keyword-only|, default: ``1e-15``
         The absolute tolerance used by `~numpy.isclose` when testing
-        normalizations and making comparisons.  Defaults to ``1e-15``.
+        normalizations and making comparisons.
 
     Raises
     ------
@@ -219,16 +219,20 @@ class IonizationStateCollection:
                 )
 
             if not isinstance(int_charge, Integral):
-                raise TypeError(f"{int_charge} is not a valid charge for {particle}.")
+                raise TypeError(  # noqa: TC301
+                    f"{int_charge} is not a valid charge for {particle}."
+                )
             elif not 0 <= int_charge <= atomic_number(particle):
                 raise ChargeError(f"{int_charge} is not a valid charge for {particle}.")
+
+        except (ChargeError, KeyError, TypeError) as exc:
+            raise IndexError(errmsg) from exc
+        else:
             return IonicLevel(
                 ion=particle_symbol(particle, Z=int_charge),
                 ionic_fraction=self.ionic_fractions[particle][int_charge],
                 number_density=self.number_densities[particle][int_charge],
             )
-        except (ChargeError, KeyError, TypeError) as exc:
-            raise IndexError(errmsg) from exc
 
     def __setitem__(self, key, value):
 
@@ -300,7 +304,7 @@ class IonizationStateCollection:
                         f"defined."
                     )
 
-        try:
+        try:  # noqa: TC101
             new_fractions = np.array(value, dtype=float)
         except TypeError as exc:
             raise TypeError(
@@ -343,16 +347,10 @@ class IonizationStateCollection:
     def __eq__(self, other):
 
         if not isinstance(other, IonizationStateCollection):
-            raise TypeError(
-                "IonizationStateCollection instance can only be compared with "
-                "other IonizationStateCollection instances."
-            )
+            return False
 
         if self.base_particles != other.base_particles:
-            raise ParticleError(
-                "Two IonizationStateCollection instances can be compared only "
-                "if the base particles are the same."
-            )
+            return False
 
         min_tol = np.min([self.tol, other.tol])
 
@@ -363,10 +361,6 @@ class IonizationStateCollection:
             this = getattr(self, attribute)
             that = getattr(other, attribute)
 
-            # TODO: Maybe create a function in utils called same_enough
-            # TODO: that would take care of all of these disparate
-            # TODO: equality measures.
-
             this_equals_that = np.any(
                 [
                     this == that,
@@ -437,12 +431,6 @@ class IonizationStateCollection:
         ------
         `~plasmapy.particles.exceptions.ParticleError`
             If the ionic fractions cannot be set.
-
-        `TypeError`
-            If ``inputs`` is not a `list`, `tuple`, or `dict` during
-            instantiation, or if ``inputs`` is not a `dict` when it is
-            being set.
-
         """
 
         # A potential problem is that using item assignment on the
@@ -496,7 +484,7 @@ class IonizationStateCollection:
             # The particles whose ionization states are to be recorded
             # should be elements or isotopes but not ions or neutrals.
 
-            for key in particles.keys():
+            for key in particles:
                 is_element = particles[key].is_category("element")
                 has_charge_info = particles[key].is_category(
                     any_of=["charged", "uncharged"]
@@ -723,11 +711,11 @@ class IonizationStateCollection:
                 new_keys_dict = {}
                 for old_key in old_keys:
                     new_keys_dict[particle_symbol(old_key)] = old_key
-            except ParticleError:
+            except ParticleError as ex:
                 raise ParticleError(
                     f"The key {repr(old_key)} in the abundances "
                     f"dictionary is not a valid element or isotope."
-                )
+                ) from ex
 
             new_elements = new_keys_dict.keys()
 
@@ -874,18 +862,17 @@ class IonizationStateCollection:
 
         Parameters
         ----------
-        include_neutrals : `bool`, optional, keyword-only
+        include_neutrals : `bool`, optional, |keyword-only|, default: `True`
             If `True`, include neutrals when calculating the mean values
             of the different particles.  If `False`, exclude neutrals.
-            Defaults to `True`.
 
-        use_rms_charge : `bool`, optional, keyword-only
-            If `True`, use the root mean square charge instead of the
-            mean charge. Defaults to `False`.
+        use_rms_charge : `bool`, optional, |keyword-only|, default: `False`
+            If `True`, use the root-mean-square charge instead of the
+            mean charge.
 
-        use_rms_mass : `bool`, optional, keyword-only
-            If `True`, use the root mean square mass instead of the mean
-            mass. Defaults to `False`.
+        use_rms_mass : `bool`, optional, |keyword-only|, default: `False`
+            If `True`, use the root-mean-square mass instead of the mean
+            mass.
 
         Raises
         ------
@@ -940,18 +927,16 @@ class IonizationStateCollection:
             abundances=all_abundances,
         )
 
-    def summarize(self, minimum_ionic_fraction: Real = 0.01) -> None:
+    def summarize(self, minimum_ionic_fraction: Real = 0.01) -> NoReturn:
         """
-        Print quicklook information for an
-        `~plasmapy.particles.ionization_state_collection.IonizationStateCollection`
-        instance.
+        Print quicklook information.
 
         Parameters
         ----------
-        minimum_ionic_fraction: `Real`
+        minimum_ionic_fraction : `Real`, default: ``0.01``
             If the ionic fraction for a particular ionization state is
             below this level, then information for it will not be
-            printed.  Defaults to 0.01.
+            printed.
 
         Examples
         --------
@@ -975,7 +960,6 @@ class IonizationStateCollection:
         T_e = 1.20e+04 K
         kappa = 3.40
         ----------------------------------------------------------------
-
         """
         separator_line = 64 * "-"
 
