@@ -7,7 +7,7 @@ from typing import Dict
 
 from plasmapy.particles import alpha, electron, neutron, proton
 from plasmapy.particles.atomic import atomic_number
-from plasmapy.particles.exceptions import ChargeError, InvalidParticleError
+from plasmapy.particles.exceptions import InvalidParticleError
 from plasmapy.particles.nuclear import nuclear_reaction_energy
 from plasmapy.particles.particle_class import (
     CustomParticle,
@@ -15,7 +15,7 @@ from plasmapy.particles.particle_class import (
     Particle,
     ParticleLike,
 )
-from plasmapy.particles.particle_collections import ionic_levels, ParticleList
+from plasmapy.particles.particle_collections import ParticleList
 
 custom_particle = CustomParticle(mass=1e-25 * u.kg, charge=1e-18 * u.C)
 dimensionless_particle = DimensionlessParticle(mass=1.25, charge=1.58)
@@ -245,7 +245,7 @@ def test_add_particle_list_and_particle(various_particles):
     """
     new_particle_list = various_particles + electron
     assert new_particle_list[-1] == electron
-    assert new_particle_list[0:-1] == various_particles
+    assert new_particle_list[:-1] == various_particles
     assert isinstance(new_particle_list, ParticleList)
 
 
@@ -327,6 +327,43 @@ def test_particle_multiplication(method, particle):
     assert particle_list == [particle, particle, particle]
 
 
+@pytest.mark.parametrize(
+    "particles, args, kwargs, expected",
+    [
+        [
+            ["electron", "proton", "neutron"],
+            ["lepton"],
+            {},
+            [True, False, False],
+        ],
+        [
+            ["electron", "proton", "neutron"],
+            [],
+            {"require": "lepton"},
+            [True, False, False],
+        ],
+        [
+            ["electron", "proton", "neutron"],
+            [],
+            {"exclude": "lepton"},
+            [False, True, True],
+        ],
+        [
+            ["electron", "proton", "neutron"],
+            [],
+            {"any_of": {"lepton", "charged"}},
+            [True, True, False],
+        ],
+    ],
+)
+def test_particle_list_is_category(particles, args, kwargs, expected):
+    """
+    Test that ``ParticleList.is_category()`` behaves as expected.
+    """
+    sample_list = ParticleList(particles)
+    assert sample_list.is_category(*args, **kwargs) == expected
+
+
 def test_mean_particle():
     """
     Test that ``ParticleList.average_particle()`` returns a particle with
@@ -375,7 +412,7 @@ def test_root_mean_square_particle(use_rms_charge, use_rms_mass):
     assert u.isclose(average_particle.charge, expected_average_charge, rtol=1e-14)
 
     if use_rms_mass:
-        expected_average_mass = np.sqrt((proton.mass ** 2 + electron.mass ** 2) / 2)
+        expected_average_mass = np.sqrt((proton.mass**2 + electron.mass**2) / 2)
     else:
         expected_average_mass = (proton.mass + electron.mass) / 2
 
@@ -456,36 +493,3 @@ def test_particle_list_with_no_arguments():
     empty_particle_list = ParticleList()
     assert isinstance(empty_particle_list, ParticleList)
     assert len(empty_particle_list) == 0
-
-
-def test_ion_list_example():
-    ions = ionic_levels("He-4")
-    np.testing.assert_equal(ions.charge_number, [0, 1, 2])
-    assert ions.symbols == ["He-4 0+", "He-4 1+", "He-4 2+"]
-
-
-@pytest.mark.parametrize(
-    "particle, min_charge, max_charge, expected_charge_numbers",
-    [
-        ("H-1", 0, 1, [0, 1]),
-        ("p+", 1, 1, [1]),
-        (Particle("p+"), 0, 0, [0]),
-        ("C", 3, 5, [3, 4, 5]),
-    ],
-)
-def test_ion_list(particle, min_charge, max_charge, expected_charge_numbers):
-    """Test that inputs to ionic_levels are interpreted correctly."""
-    particle = Particle(particle)
-    ions = ionic_levels(particle, min_charge, max_charge)
-    np.testing.assert_equal(ions.charge_number, expected_charge_numbers)
-    assert ions[0].element == particle.element
-    if particle.is_category("isotope"):
-        assert ions[0].isotope == particle.isotope
-
-
-@pytest.mark.parametrize(
-    "element, min_charge, max_charge", [("Li", 0, 4), ("Li", 3, 2)]
-)
-def test_invalid_inputs_to_ion_list(element, min_charge, max_charge):
-    with pytest.raises(ChargeError):
-        ionic_levels(element, min_charge, max_charge)
