@@ -3,9 +3,9 @@ __all__ = ["HDF5Reader"]
 import astropy.units as u
 import h5py
 import numpy as np
-import os
 
 from packaging.version import Version
+from pathlib import Path
 
 from plasmapy.plasma.exceptions import DataStandardError
 from plasmapy.plasma.plasma_base import GenericPlasma
@@ -55,7 +55,7 @@ class HDF5Reader(GenericPlasma):
     def __init__(self, hdf5, **kwargs):
         super().__init__(**kwargs)
 
-        if not os.path.isfile(hdf5):
+        if not Path(hdf5).is_file():
             raise FileNotFoundError(f"Could not find file: '{hdf5}'")
 
         h5 = h5py.File(hdf5, "r")
@@ -80,7 +80,7 @@ class HDF5Reader(GenericPlasma):
             if _valid_version(openPMD_version):
                 return True
             else:
-                raise DataStandardError(
+                raise DataStandardError(  # noqa: TC301
                     f"We currently only support HDF5 versions"
                     f"starting from v{_OUTDATED_VERSION} and "
                     f"lower than v{_NEWER_VERSION}. You can "
@@ -88,10 +88,10 @@ class HDF5Reader(GenericPlasma):
                     f"version. For more information; see "
                     f"https://github.com/openPMD/openPMD-updater"
                 )
-        except KeyError:
+        except KeyError as ex:
             raise DataStandardError(
                 "Input HDF5 file does not go on with standards defined by OpenPMD"
-            )
+            ) from ex
 
     @property
     def electric_field(self):
@@ -148,8 +148,7 @@ class HDF5Reader(GenericPlasma):
         hdf5 = kwargs.get("hdf5")
         openPMD = kwargs.get("openPMD")
 
-        isfile = os.path.isfile(hdf5)
-        if not isfile:
+        if not Path(hdf5).is_file():
             raise FileNotFoundError(f"Could not find file: '{hdf5}'")
 
         if "openPMD" not in kwargs:
